import yt
import constants as c
import matplotlib.pyplot as plt
import numpy as np
import h5py
from astropy.io import ascii

host = '/mnt/zfs-pool/home/proys.manuel.zamora/'

tini = 20
tend = 20
step = 1
subbox   = 4. # subregion size in pc

dirname = 'Vianey/Simulations/monocf/'
basename = host+dirname+ 'sim_hdf5_plt_cnt_'
basepart = host+dirname+'sim_hdf5_part_'
fileout='monoB0.txt'

meandens     = []
densgasmass  = []
massinregion = []
massinbox    = []
simtime      = []
bvelinregion = []
totmasssink  = []
nsinks       = []

for i in range(tini, tend+1, step):

 fn = basename + str(i).zfill(4)
 fs = basepart + str(i).zfill(4)

 print('============================================================================')
 print(fn)
 ds = yt.load(fn, particle_filename=fs)
 ad = ds.all_data()

 # Simulation time:
 time = ds.current_time.in_units("Myr")
 simtime.append(round(time,4))

 # Entire box information ==========================================================

 # Mass:
 massbox  = ad.quantities.total_mass()
 totmassb = massbox[0]/c.Msun
 massinbox.append(round(totmassb,4))
 print('massbox', totmassb)

 # Velocity:
 velbox  = ad.quantities.bulk_velocity()
 ivelbox = velbox[1].in_units('km/s')

 # Subregion information  ==========================================================

 # Define a subregion:
 subbox = subbox*c.pc
 reg = ds.r[-subbox:+subbox, -subbox:+subbox, -subbox:+subbox]

 # Mean density:
 dens_av = reg.mean("dens",weight = "cell_volume")  #reg["dens"].sum()
 print('Densidad promedio = ', dens_av)
 meandens.append(dens_av)

 # Dense gas mass:
 densg = reg.cut_region(["obj['dens'] >= 3.9306641e-22"]) #>=100 (mu=2.35)
 mdens = densg.quantities.total_mass()
 print('Masa de gas denso = ', mdens)
 Mc = mdens[0]/c.Msun # We get just the number in units of Msun
 print('Masa de gas denso = ', Mc, ' Msun')
 densgasmass.append(Mc)

# Mass in region
 massreg = reg.quantities.total_mass()
 totmassr = massreg[0]/c.Msun
 massinregion.append(round(totmassr,4))

 # Velocity
 bvel = reg.quantities.bulk_velocity()
 buvel = bvel[1].in_units('km/s')
 print('bvel', bvel, buvel)
 bvelinregion.append(round(buvel,4))

 # Sink particles info: ============================================================
 isink = len(ds.particle_type_counts)
 if isink > 0:
  #sinks
  ppm = ad["particle_mass"]
  msink = sum(ppm)/c.Msun
  nsink = len(ppm)
  totmasssink.append(round(msink,4))
  nsinks.append(nsink)
  print('M_sink', msink)
  print('nsink', nsink)
 else:
    totmasssink.append(0)
    nsinks.append(0)
    print('No sinks yet')

#     Myr       g cm-3      msun        msun      msun         km s-1
params = [simtime, meandens, massinregion, massinbox, bvelinregion, nsinks, totmasssink]
data = np.array(params)

data = data.T

#with open(fileout, 'w') as datafile_id:
#  ascii.write(data, datafile_id)



